@@ -1,7 +1,7 @@
 '''
 rquote
 
-A stock history data api
+A stock history data api and related tools
 
 Copyright (c) 2021 Roi ZHAO
 
@@ -10,3 +10,4 @@ Copyright (c) 2021 Roi ZHAO
 from .rquote import get_price, get_stock_concepts, get_concept_stocks
 from .rquote import get_all_concepts, get_all_industries
 from .utils import CommonUtils, WebUtils, BasicFactors, DataFormatter, reqget
+from .plots import PlotUtils
